@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kinesis._jsii
@@ -21,9 +21,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-kinesisfirehose-s3-and-kinesisanalytics",
-    "1.58.0",
+    "1.70.0",
     __name__[0:-6],
-    "aws-kinesisfirehose-s3-and-kinesisanalytics@1.58.0.jsii.tgz",
+    "aws-kinesisfirehose-s3-and-kinesisanalytics@1.70.0.jsii.tgz",
 )
 
 __all__ = [
